@@ -1,5 +1,3 @@
-context("Task")
-
 test_that("Feature columns can be reordered", {
   bh = load_dataset("BostonHousing", "mlbench")
   task = tsk("boston_housing")
@@ -40,11 +38,6 @@ test_that("Rows return ordered", {
 
   x = task$data(rows = sample(nrow(data), 50))
   expect_integer(x$t, sorted = TRUE, any.missing = FALSE)
-
-  tab = task$order
-  expect_data_table(tab, ncols = 2, nrows = task$nrow)
-  expect_set_equal(names(tab), c("row_id", "order"))
-  expect_integer(rev(tab$order), sorted = TRUE)
 })
 
 test_that("Rows return ordered with multiple order cols", {
